@@ -57,15 +57,21 @@ class Battery:
 
 class BatteryCharge(Battery):
     def consumption(self):
-        return self.battery_info["VOLTAGE_NOW"] * self.battery_info["CURRENT_NOW"]  # V  * A = W
+        if "VOLTAGE_NOW" in self.battery_info and "CURRENT_NOW" in self.battery_info:
+            return self.battery_info["VOLTAGE_NOW"] * self.battery_info["CURRENT_NOW"]  # V * A = W
+        else:
+            return -1
 
     def _percentage(self, design):
         return self.battery_info["CHARGE_NOW"] / self.battery_info["CHARGE_FULL" + design]
 
     def remaining(self):
         if self.status() == "Discharging":
-            # Ah / A = h * 60 min = min
-            return self.battery_info["CHARGE_NOW"] / self.battery_info["CURRENT_NOW"] * 60
+            if "CHARGE_NOW" in self.battery_info and "CURRENT_NOW" in self.battery_info:
+                # Ah / A = h * 60 min = min
+                return self.battery_info["CHARGE_NOW"] / self.battery_info["CURRENT_NOW"] * 60
+            else:
+                return -1
         else:
             return (self.battery_info["CHARGE_FULL"] - self.battery_info["CHARGE_NOW"]) / self.battery_info["CURRENT_NOW"] * 60
 
@@ -109,6 +115,8 @@ class BatteryChecker(IntervalModule):
         ("alert_format_body", "The body text of the notification, all formatters can be used"),
         ("path", "Override the default-generated path"),
         ("status", "A dictionary mapping ('DIS', 'CHR', 'FULL') to alternative names"),
+        ("color", "The text color"),
+        ("critical_color", "The critical color"),
     )
     battery_ident = "BAT0"
     format = "{status} {remaining}"
@@ -122,6 +130,8 @@ class BatteryChecker(IntervalModule):
     alert_percentage = 10
     alert_format_title = "Low battery"
     alert_format_body = "Battery {battery_ident} has only {percentage:.2f}% ({remaining:%E%hh:%Mm}) remaining!"
+    color = "#ffffff"
+    critical_color = "#ff0000"
 
     path = None
 
@@ -132,7 +142,7 @@ class BatteryChecker(IntervalModule):
 
     def run(self):
         urgent = False
-        color = "#ffffff"
+        color = self.color
 
         battery = Battery.create(self.path)
 
@@ -152,7 +162,7 @@ class BatteryChecker(IntervalModule):
                 fdict["status"] = "DIS"
                 if battery.percentage() <= self.alert_percentage:
                     urgent = True
-                    color = "#ff0000"
+                    color = self.critical_color
             else:
                 fdict["status"] = "CHR"
         else:
@@ -173,5 +183,5 @@ class BatteryChecker(IntervalModule):
             "full_text": formatp(self.format, **fdict).strip(),
             "instance": self.battery_ident,
             "urgent": urgent,
-            "color": color
+            "color": color,
         }
