@@ -16,12 +16,12 @@ class Clock(IntervalModule):
 
     settings = (
         ("format", "stftime format string, `None` means to use the default, locale-dependent format"),
+        ("color", "RGB hexadecimal code color specifier, default to #ffffff, set to `i3Bar` to use i3 bar default"),
     )
     format = None
+    color = "#ffffff"
     interval = 1
 
-    c = ["#ffffff", "#cccccc"]
-
     def init(self):
         if self.format is None:
             lang = os.environ.get('LANG', None)
@@ -36,9 +36,9 @@ class Clock(IntervalModule):
                 self.format = "%a %-d %b %X"
 
     def run(self):
-        self.c.reverse()
         self.output = {
             "full_text": datetime.datetime.now().strftime(self.format),
             "urgent": False,
-            "color": self.c[0],
         }
+        if self.color != "i3Bar":
+            self.output["color"] = self.color
