@@ -1,13 +1,7 @@
 
-import time
-
 from i3pystatus.core.settings import SettingsBase
 from i3pystatus.core.threading import Manager
-from i3pystatus.core.util import convert_position, chain
-
-__all__ = [
-    "Module", "AsyncModule", "IntervalModule",
-]
+from i3pystatus.core.util import convert_position
 
 
 class Module(SettingsBase):
@@ -24,13 +18,6 @@ class Module(SettingsBase):
             self.output["instance"] = str(id(self))
             json.insert(convert_position(self.position, json), self.output)
 
-    def test(self):
-        """
-        Return True if settings seem ok (i.e. login credentials and such are valid)
-        or a string describing the problem
-        """
-        return True
-
     def run(self):
         pass
 
@@ -40,9 +27,9 @@ class Module(SettingsBase):
         elif button == 3:  # Right mouse button
             self.on_rightclick()
 
-    @chain
     def move(self, position):
         self.position = position
+        return self
 
     def on_leftclick(self):
         pass
@@ -50,11 +37,19 @@ class Module(SettingsBase):
     def on_rightclick(self):
         pass
 
-    def __repr__(self):
-        return self.__class__.__name__
+
+class IntervalModuleMeta(type):
+    """Add interval setting to `settings` attribute if it does not exist."""
+
+    def __init__(cls, name, bases, namespace):
+        super(IntervalModuleMeta, cls).__init__(name, bases, namespace)
+        if not hasattr(cls, 'settings'):
+            cls.settings = tuple()
+        if not 'interval' in SettingsBase.flatten_settings(cls.settings):
+            cls.settings += ('interval', )
 
 
-class IntervalModule(Module):
+class IntervalModule(Module, metaclass=IntervalModuleMeta):
     interval = 5  # seconds
     managers = {}
 
@@ -65,11 +60,7 @@ class IntervalModule(Module):
             am = Manager(self.interval)
             am.append(self)
             IntervalModule.managers[self.interval] = am
-
-    @classmethod
-    def _start(cls):
-        for manager in cls.managers.values():
-            manager.start()
+            am.start()
 
     def __call__(self):
         self.run()
@@ -79,7 +70,3 @@ class IntervalModule(Module):
 
         Do not rely on this being called from the same thread at all times.
         If you need to always have the same thread context, subclass AsyncModule."""
-
-START_HOOKS = (
-    IntervalModule._start,
-)
