@@ -7,9 +7,6 @@
 # The plugin must be active and thunderbird running for the module to work
 # properly.
 
-import json
-import threading
-import time
 from functools import partial
 
 import dbus
@@ -25,8 +22,7 @@ class Thunderbird(Backend):
     This class listens for dbus signals emitted by
     the dbus-sender extension for thunderbird.
 
-    Requires
-    * python-dbus
+    Requires python-dbus
     """
 
     _unread = set()
