@@ -9,9 +9,10 @@ class PulseAudio(Module):
     Shows volume of default PulseAudio sink (output).
 
     Available formatters:
+
     * `{volume}` — volume in percent (0...100)
     * `{db}` — volume in decibels relative to 100 %, i.e. 100 % = 0 dB, 50 % = -18 dB, 0 % = -infinity dB
-    (the literal value for -infinity is `-∞`)
+      (the literal value for -infinity is `-∞`)
     * `{muted}` — the value of one of the `muted` or `unmuted` settings
     """
 
@@ -40,7 +41,7 @@ class PulseAudio(Module):
         # connection to Pulseaudio
         _mainloop = pa_threaded_mainloop_new()
         _mainloop_api = pa_threaded_mainloop_get_api(_mainloop)
-        context = pa_context_new(_mainloop_api, 'peak_demo'.encode("ascii"))
+        context = pa_context_new(_mainloop_api, "i3pystatus_pulseaudio".encode("ascii"))
 
         pa_context_set_state_callback(context, self._context_notify_cb, None)
         pa_context_connect(context, None, 0, None)
