@@ -12,7 +12,8 @@ class Wireless(Network):
     Requires the PyPI packages `netifaces-py3` and `basiciw`.
 
     This is based on the network module, so all options and formatters are
-    the same, except for these additional formatters:
+    the same, except for these additional formatters and that detached_down doesn't work.
+
     * `{essid}` — ESSID of currently connected wifi
     * `{freq}` — Current frequency
     * `{quality}` — Link quality in percent
@@ -37,4 +38,4 @@ class Wireless(Network):
             fdict["essid"] = ""
             fdict["freq"] = fdict["quality"] = 0.0
 
-        return (color, format, fdict, up)
+        return color, format, fdict, up
